--[[-----------------------------------------------------------------

EnergyMonitor Options defintions

This file adds the setupOptions function to the addon which gets
called during OnInitialization.

Author: lokicoyote
File Date: 2008-11-17T23:43:14Z
File Revision: 63
Project Revision: 73
Project Version: v0.10.4

--]]-----------------------------------------------------------------

local kAddon = "EnergyMonitor"

-- Cache often used global functions
local pairs = _G.pairs

---------------------------------------------------------------------
-- Library constants
---------------------------------------------------------------------

local addon = LibStub("AceAddon-3.0"):GetAddon(kAddon)
local L = LibStub("AceLocale-3.0"):GetLocale(kAddon, true)

---------------------------------------------------------------------
-- Local constants
---------------------------------------------------------------------

local kSlashCommand = "emon"

---------------------------------------------------------------------
-- loadOptions functions
---------------------------------------------------------------------

local function loadOptions(self)
	local retval = self.cache.options
	if nil == retval then
		retval = false
		self.cache.options = false -- initialize in case of failure
		-- Load the options addon
		local result, loaded_or_msg, err = pcall(LoadAddOn, kAddon .. "_Options")
		if not result then
			self:Print(L["Error: Unable to load addon X: Y"](kAddon .. "_Options", loaded_or_msg))
		elseif not loaded_or_msg then
			self:Print(L["Error: Unable to load addon X: Y"](kAddon .. "_Options", _G[ "ADDON_" .. err ]))
		else
			local options = LibStub("AceAddon-3.0"):GetAddon(kAddon .. "_Options")
			if options and options:IsEnabled() then
				retval = options
			end
		end
		self.cache.options = retval
	end
	return retval
end

function addon:chatCommand(in_input)
	if loadOptions(self) then
		self:chatCommand(in_input)
	end
end

---------------------------------------------------------------------
-- Setup functions
---------------------------------------------------------------------

function addon:setupOptions()
	self:RegisterChatCommand(kSlashCommand, "chatCommand")
	if L then
		for _, cmd in pairs(L["Slash-Commands"]) do
			self:RegisterChatCommand(cmd, "chatCommand")
		end
	end

	local frame = CreateFrame("Frame", nil, InterfaceOptionsFrame)
	frame:SetScript("OnShow", function(this)
		loadOptions(self)
		--this:SetScript("OnShow", nil)
	end)
end
